{% load static %}
<link rel="stylesheet" href="{% static 'iziToast.min.css' %}" />
<script src="{% static 'jquery.min.js' %}"></script>
<script src="{% static 'iziToast.min.js' %}"></script>
<script src="{% static 'toastr.min.js' %}"></script>

{% if messages %} {% for message in messages %}
<div style="display: none !important">{{message}}</div>
{% endfor %} {% endif %}
